==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/fixoverlappingtimesdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "fixoverlappingtimesdialog.h"

#include <qlabel.h>
#include <qgroupbox.h>
#include <qlayout.h>

#include <klocale.h>
#include <knuminput.h>

using namespace SubtitleComposer;


FixOverlappingTimesDialog::FixOverlappingTimesDialog( QWidget* parent ):
	TargetableLinesActionDialog( i18n( "Fix Overlapping Lines" ), parent )
{
	QGroupBox* buttonGroup = createGroupBox( i18n( "Settings" ) );

	QLabel* minIntervalLabel = new QLabel( i18n( "Minimum interval" ), buttonGroup );
	minIntervalLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_minIntervalSpinBox = new KIntNumInput( buttonGroup );
	m_minIntervalSpinBox->setSuffix( i18n( " msecs" ) );
	m_minIntervalSpinBox->setMinValue( 1 );
	m_minIntervalSpinBox->setMaxValue( 1000 );
	m_minIntervalSpinBox->setValue( 50 );

	QGridLayout* buttonGroupLayout = createLayout( buttonGroup );
	buttonGroupLayout->addWidget( minIntervalLabel, 0, 0 );
	buttonGroupLayout->addWidget( m_minIntervalSpinBox, 0, 1 );

	createLinesTargetGroupBox();
}

Time FixOverlappingTimesDialog::minimumInterval()
{
	return Time( m_minIntervalSpinBox->value() );
}

void FixOverlappingTimesDialog::setMinimumInterval( const Time& time )
{
	m_minIntervalSpinBox->setValue( time.toMillis() );
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/fixoverlappingtimesdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "fixoverlappingtimesdialog.h"

#include <qlabel.h>
#include <qbuttongroup.h>
#include <qlayout.h>

#include <klocale.h>
#include <knuminput.h>

using namespace SubtitleComposer;


FixOverlappingTimesDialog::FixOverlappingTimesDialog( QWidget* parent ):
	ActionWithTargetDialog( i18n( "Fix Overlapping Lines" ), parent )
{
	QButtonGroup* settingsButtonGroup = createButtonGroup( i18n( "Settings" ) );

	QLabel* minIntervalLabel = new QLabel( i18n( "Minimum interval" ), settingsButtonGroup );
	minIntervalLabel->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );

	m_minIntervalSpinBox = new KIntNumInput( settingsButtonGroup );
	m_minIntervalSpinBox->setSuffix( i18n( " msecs" ) );
	m_minIntervalSpinBox->setMinValue( 1 );
	m_minIntervalSpinBox->setMaxValue( 1000 );
	m_minIntervalSpinBox->setValue( 50 );


	createLinesTargetButtons();


	QGridLayout* settingsLayout = createLayout( settingsButtonGroup );
	settingsLayout->addWidget( minIntervalLabel, 0, 0 );
	settingsLayout->addWidget( m_minIntervalSpinBox, 0, 1 );
}

Time FixOverlappingTimesDialog::minimumInterval() const
{
	return Time( m_minIntervalSpinBox->value() );
}

void FixOverlappingTimesDialog::setMinimumInterval( const Time& time )
{
	m_minIntervalSpinBox->setValue( time.toMillis() );
}
